News for hackers. Stuff that matters.
Re:N-Queen Problem: Python 2.6.5 vs PyPy 1.5.0 by dzorz on Sunday May 29, 2011 @06:03PM (#2597729)
140x speedup was compared to optimized python version. I've tried it vs. pypy now (version 1.5) - it is 20x faster.
Re:N-Queen Problem: Python 2.6.5 vs PyPy 1.5.0 by StavrosK on Sunday May 29, 2011 @06:21PM (#2597775)
Would it be possible for you to try ShedSkin on it?
Re:N-Queen Problem: Python 2.6.5 vs PyPy 1.5.0 by dzorz on Sunday May 29, 2011 @06:48PM (#2597818)
I managed to compile the program using shedskin, but it throws a runtime error after it finds the first solution:

    ==== solution 1 =====
    (0, 2, 5, 7, 9, 4, 8, 1, 3, 6)
    terminate called after throwing an instance of '__shedskin__::TypeError*'
    Aborted
Re:N-Queen Problem: Python 2.6.5 vs PyPy 1.5.0 by StavrosK on Monday May 30, 2011 @02:07AM (#2598664)
Ah, that's too bad... Thanks for the effort, anyway.